searchData={"items":[{"type":"module","title":"NLdoc.Conversion.Docx.Zip","doc":"This module implements some helper functions for handling `.zip` files.","ref":"NLdoc.Conversion.Docx.Zip.html"},{"type":"function","title":"NLdoc.Conversion.Docx.Zip.create/2","doc":"","ref":"NLdoc.Conversion.Docx.Zip.html#create/2"},{"type":"function","title":"NLdoc.Conversion.Docx.Zip.create!/2","doc":"Create a `.zip` file from a list of files.\n\nThe first argument should be a list of paths to the files that should be included in the `.zip` file.\nIt is highly recommended to use absolute paths, though paths relative to the application's CWD will work as well.\n\nThe second argument should be the path to the `.zip` file that should be created.","ref":"NLdoc.Conversion.Docx.Zip.html#create!/2"},{"type":"function","title":"NLdoc.Conversion.Docx.Zip.extract/2","doc":"","ref":"NLdoc.Conversion.Docx.Zip.html#extract/2"},{"type":"function","title":"NLdoc.Conversion.Docx.Zip.extract!/2","doc":"Extract a `.zip` file to a directory. The first argument should be the path to the `.zip` file to extract.\nThe second argument should be the path to the directory where the contents of the `.zip` file will be extracted to.\nIf this directory does not yet exist, it will be created.\n\nThis function will raise an error if the `.zip` file does not exist, if the extraction path cannot be created,\nor if the extraction fails. If you prefer an error tuple instead, use `extract/2`.","ref":"NLdoc.Conversion.Docx.Zip.html#extract!/2"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx","doc":"The `NLdoc.Conversion.Reader.Docx` struct represents an opened Docx file.\n\nThis module provides functions for opening, converting and reading from Docx files.\n\nNote: after opening a Docx file with `open!/1`, it is highly recommended to call `close!/1`\nto clean up the temporary directory in which the Docx file was extracted.","ref":"NLdoc.Conversion.Reader.Docx.html"},{"type":"module","title":"Package Structure - NLdoc.Conversion.Reader.Docx","doc":"The `NLdoc.Conversion.Reader.Docx` package is structured as follows:\n\n- `NLdoc.Conversion.Reader.Docx`: contains the main `Docx` struct and functions for opening and closing Docx files.\n                           `convert!/1` is delegated to `NLdoc.Conversion.Reader.Docx.Convert`.\n- `NLdoc.Conversion.Reader.Docx.AST`: implements structures that represent the information contained in the files of a Docx document.\n                               This is our Abstract Syntax Tree (AST), our internal representation of the contents of everything in a Docx document.\n- `NLdoc.Conversion.Reader.Docx.Files`: implements everything related to what files are in a Docx document:\n                                 `[Content_Types].xml`, `docProps/core.xml`, `document.xml`, `numbering.xml`,\n                                 `styles.xml`, `.rels` files etc.\n- `NLdoc.Conversion.Reader.Docx.Convert`: implements the actual conversion of AST to NLdoc spec.","ref":"NLdoc.Conversion.Reader.Docx.html#module-package-structure"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.close!/1","doc":"Close a `Docx` struct, removing the temporary directory in which the Docx file was extracted.\nAfter this, the `Docx` struct can no longer be used as input to any functions in this module.","ref":"NLdoc.Conversion.Reader.Docx.html#close!/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.convert!/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.html#convert!/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.open!/1","doc":"Open a Docx file and extract its contents to a temporary directory, raising errors when any of these steps fail.\nReturns a `Docx` struct that can be used with the rest of the functions in this module.\nWhen you're done with the `Docx` struct, you should call `close!/1` to clean up the temporary directory.","ref":"NLdoc.Conversion.Reader.Docx.html#open!/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts","doc":"This module defines a struct that represents a `w:rFonts` object in a Word document.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.font/1","doc":"Given a special font type or special font name, returns a module that implements `NLdoc.Conversion.Reader.Docx.AST.Fonts.FontBehaviour`\nfor converting characters in that font to UTF-8.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html#font/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.is_special_font/1","doc":"Returns true for font types or font names that are special fonts, i.e. they won't render properly on the\nweb and will need conversion to UTF-8.\n\nCan also be used as a guard clause.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html#is_special_font/1"},{"type":"macro","title":"Examples - NLdoc.Conversion.Reader.Docx.AST.Fonts.is_special_font/1","doc":"iex> import NLdoc.Conversion.Reader.Docx.AST.Fonts, only: [is_special_font: 1]\n    iex>\n    iex> is_special_font(:wingdings)\n    true\n    iex> is_special_font(:wingdings2)\n    true\n    iex> is_special_font(:wingdings3)\n    true\n    iex> is_special_font(:webdings)\n    true\n    iex> is_special_font(:symbol)\n    true\n    iex> is_special_font(\"Wingdings\")\n    true\n    iex> is_special_font(\"Wingdings 2\")\n    true\n    iex> is_special_font(\"Wingdings 3\")\n    true\n    iex> is_special_font(\"Webdings\")\n    true\n    iex> is_special_font(\"Symbol\")\n    true\n    iex> is_special_font(:utf8)\n    false\n    iex> is_special_font(\"UTF8\")\n    false","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html#is_special_font/1-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.merge/2","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html#merge/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.parse/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html#parse/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.special_font/0","doc":"This type defines special fonts that won't render properly on the web and will need conversion to UTF-8.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html#t:special_font/0"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.html#t:t/0"},{"type":"behaviour","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.FontBehaviour","doc":"This module defines the behaviour of a font module.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.FontBehaviour.html"},{"type":"callback","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.FontBehaviour.to_utf8/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.FontBehaviour.html#c:to_utf8/1"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.SpecialFont","doc":"This module provides a basis for implementing UTF-8 conversions of special fonts like Symbol, Wingdings and Webdings.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.SpecialFont.html"},{"type":"module","title":"Usage - NLdoc.Conversion.Reader.Docx.AST.Fonts.SpecialFont","doc":"Create a module for your font, `use` this module and provide a `symbols` map\nmapping codepoints in your font to UTF-8 codepoints.\n\nFor example:\n\n    defmodule NLdoc.Conversion.Reader.Docx.AST.Fonts.Symbol do\n      use NLdoc.Conversion.Reader.Docx.AST.Fonts.SpecialFont,\n        symbols: %{\n          0x20 => 0xA0,\n          0x21 => 0x21,\n          # etc ...\n        }\n    end","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.SpecialFont.html#module-usage"},{"type":"module","title":"Acknowledgements - NLdoc.Conversion.Reader.Docx.AST.Fonts.SpecialFont","doc":"Many thanks to Pandoc author [John MacFarlane (jgm)](https://github.com/jgm) for helping us map the Wingdings and Webdings fonts\nand helping us figure out how to perform the conversion to UTF-8.\n\n@see https://github.com/jgm/pandoc/issues/9220","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.SpecialFont.html#module-acknowledgements"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Symbol","doc":"This module maps codepoints in the Symbol font family to Unicode UTF-8 codepoints.\n\n@see For more info about this mapping:\n- https://en.wikipedia.org/wiki/Symbol_(typeface)\n- https://www.alanwood.net/demos/symbol.html","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Symbol.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Symbol.to_utf8/1","doc":"Converts a string to UTF-8 using the special font's codepoints.\nAlternatively, converts a single codepoint to UTF-8 using the special font's codepoints.\nAny unrecognized codepoints are converted to nil and removed from the string.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Symbol.html#to_utf8/1"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.UTF8","doc":"This module translates characters in UTF-8 to UTF-8 characters.\nIt's essentially a no-op.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.UTF8.html"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Webdings","doc":"This module maps codepoints in Microsoft's Webdings font family to standard Unicode UTF-8 codepoints.\n\n@see For more info about this mapping:\n- https://en.wikipedia.org/wiki/Webdings\n- https://www.alanwood.net/demos/webdings.html\n- https://github.com/jgm/pandoc/issues/9220#issuecomment-1828267608","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Webdings.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Webdings.to_utf8/1","doc":"Converts a string to UTF-8 using the special font's codepoints.\nAlternatively, converts a single codepoint to UTF-8 using the special font's codepoints.\nAny unrecognized codepoints are converted to nil and removed from the string.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Webdings.html#to_utf8/1"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings","doc":"This module maps codepoints in Microsoft's Wingdings font family to standard Unicode UTF-8 codepoints.\n\n@see For more info about this mapping:\n- https://en.wikipedia.org/wiki/Wingdings\n- https://www.alanwood.net/demos/wingdings.html\n- https://github.com/jgm/pandoc/issues/9220#issuecomment-1828260120","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings.to_utf8/1","doc":"Converts a string to UTF-8 using the special font's codepoints.\nAlternatively, converts a single codepoint to UTF-8 using the special font's codepoints.\nAny unrecognized codepoints are converted to nil and removed from the string.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings.html#to_utf8/1"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings2","doc":"This module maps codepoints in Microsoft's Wingdings 2 font family to standard Unicode UTF-8 codepoints.\n\n@see For more info about this mapping:\n- https://en.wikipedia.org/wiki/Wingdings\n- https://www.alanwood.net/demos/wingdings-2.html\n- https://github.com/jgm/pandoc/issues/9220#issuecomment-1828263607","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings2.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings2.to_utf8/1","doc":"Converts a string to UTF-8 using the special font's codepoints.\nAlternatively, converts a single codepoint to UTF-8 using the special font's codepoints.\nAny unrecognized codepoints are converted to nil and removed from the string.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings2.html#to_utf8/1"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings3","doc":"This module maps codepoints in Microsoft's Wingdings 3 font family to standard Unicode UTF-8 codepoints.\n\n@see For more info about this mapping:\n- https://en.wikipedia.org/wiki/Wingdings\n- https://www.alanwood.net/demos/wingdings-3.html\n- https://github.com/jgm/pandoc/issues/9220#issuecomment-1828265205","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings3.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings3.to_utf8/1","doc":"Converts a string to UTF-8 using the special font's codepoints.\nAlternatively, converts a single codepoint to UTF-8 using the special font's codepoints.\nAny unrecognized codepoints are converted to nil and removed from the string.","ref":"NLdoc.Conversion.Reader.Docx.AST.Fonts.Wingdings3.html#to_utf8/1"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Numbering","doc":"This module defines a struct that represents a numbering definition in a Word document\nas found in files like `word/numbering.xml`","ref":"NLdoc.Conversion.Reader.Docx.AST.Numbering.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Numbering.style_type/1","doc":"Translates the `format` field of a numbering definition into an NLdoc spec style type for ordered or unordered lists.","ref":"NLdoc.Conversion.Reader.Docx.AST.Numbering.html#style_type/1"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.AST.Numbering.style_type/1","doc":"iex> alias NLdoc.Conversion.Reader.Docx.AST.Numbering\n    iex> Numbering.style_type(\"decimal\")\n    :decimal\n    iex> Numbering.style_type(\"lowerLetter\")\n    :\"lower-alpha\"\n    iex> Numbering.style_type(\"disc\")\n    :disc\n    iex> Numbering.style_type(nil)\n    :disc\n    iex> Numbering.style_type(%Numbering{id: \"1\", level: 1, format: \"decimal\", start: 3})\n    :decimal","ref":"NLdoc.Conversion.Reader.Docx.AST.Numbering.html#style_type/1-examples"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.Numbering.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Numbering.html#t:t/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Numbering.to_list/1","doc":"Converts a numbering definition into an NLdoc spec ordered or unordered list based on the style type as determined by the `format` field.","ref":"NLdoc.Conversion.Reader.Docx.AST.Numbering.html#to_list/1"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.AST.Numbering.to_list/1","doc":"iex> alias NLdoc.Conversion.Reader.Docx.AST.Numbering\n    iex> alias NLdoc.Spec.{OrderedList, UnorderedList}\n    iex> Numbering.to_list(%Numbering{id: \"1\", level: 1, format: \"decimal\", start: 3}) |> Map.put(:id, nil)\n    %OrderedList{start: 3, style_type: :decimal, reversed: false}\n    iex> Numbering.to_list(%Numbering{id: \"2\", level: 1, format: \"lowerLetter\", start: -1}) |> Map.put(:id, nil)\n    %OrderedList{start: -1, style_type: :\"lower-alpha\", reversed: false}\n    iex> Numbering.to_list(%Numbering{id: \"3\", level: 1, format: \"disc\", start: 1}) |> Map.put(:id, nil)\n    %UnorderedList{style_type: :disc}","ref":"NLdoc.Conversion.Reader.Docx.AST.Numbering.html#to_list/1-examples"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.NumberingProperties","doc":"This module defines a struct that represents a `w:numPr` (numbering properties) object in a Word document.\n\nSee http://officeopenxml.com/WPparagraphProperties.php, element `numPr` for more information on what a\n`w:numPr` object may contain.","ref":"NLdoc.Conversion.Reader.Docx.AST.NumberingProperties.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.NumberingProperties.parse/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.NumberingProperties.html#parse/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.NumberingProperties.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.NumberingProperties.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.ParagraphProperties","doc":"This module defines a struct that represents a `w:pPr` (paragraph properties) object in a Word document.\n\nSee http://officeopenxml.com/WPparagraphProperties.php for more information on what a `w:pPr` object may contain.","ref":"NLdoc.Conversion.Reader.Docx.AST.ParagraphProperties.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.ParagraphProperties.parse/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.ParagraphProperties.html#parse/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.ParagraphProperties.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.ParagraphProperties.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Relationship","doc":"This module defines a struct that represents a relationship in a Word document\nas found in files like `word/_rels/document.xml`.","ref":"NLdoc.Conversion.Reader.Docx.AST.Relationship.html"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.Relationship.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Relationship.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.RunProperties","doc":"This module defines a struct that represents a `w:rPr` (run properties) object in a Word document.\n\nSee http://officeopenxml.com/WPtextFormatting.php for more information on what a `w:rPr` object may contain.","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.merge/2","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html#merge/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.parse/2","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html#parse/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.parse_bool/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html#parse_bool/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.parse_vert_align/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html#parse_vert_align/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.t/0","doc":"A struct representing the run properties of a run of text in a Word document.\n\nDefinition of values:\n- `true`: explicitly active\n- `false`: explicitly inactive\n- `nil`: implicitly inactive","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html#t:t/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.to_text_styling/1","doc":"Converts a `RunProperties` struct to a list of `NLdoc.Spec.text_style()` values.\nThe list is sorted in alphabetical order to ensure consistent output.","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html#to_text_styling/1"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.AST.RunProperties.to_text_styling/1","doc":"iex> alias NLdoc.Conversion.Reader.Docx.AST.RunProperties\n    iex> props = %RunProperties{\n    ...>   style_id: \"test\",\n    ...>   bold: true,\n    ...>   italic: false,\n    ...>   underline: false,\n    ...>   strike: false,\n    ...>   superscript: false,\n    ...>   subscript: false,\n    ...>   code: false,\n    ...>   fonts: nil\n    ...> }\n    iex> RunProperties.to_text_styling(props)\n    [:bold]\n    iex> RunProperties.to_text_styling(%RunProperties{props | italic: true, underline: true})\n    [:bold, :italic, :underline]\n    iex> RunProperties.to_text_styling(%RunProperties{props | superscript: true, italic: true, underline: true})\n    [:bold, :italic, :superscript, :underline]\n    iex> RunProperties.to_text_styling(%RunProperties{style_id: \"all\", bold: true, italic: true, underline: true, strike: true, superscript: true, subscript: true, code: true, fonts: nil})\n    [:bold, :code, :italic, :strikethrough, :subscript, :superscript, :underline]","ref":"NLdoc.Conversion.Reader.Docx.AST.RunProperties.html#to_text_styling/1-examples"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.AST.Style","doc":"This module defines a struct that represents a style in a Word document.","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.AST.Style.heading_level/1","doc":"Get the heading level of a heading style from its name (case-insensitive)\nThe style must have type `:heading`.","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#heading_level/1"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.AST.Style.heading_level/1","doc":"iex> alias NLdoc.Conversion.Reader.Docx.AST.Style\n    iex> Style.heading_level(%Style{id: \"test\", based_on: nil, type: :heading, name: \"heading 1\"})\n    1\n    iex> Style.heading_level(%Style{id: \"test\", based_on: nil, type: :heading, name: \"heading 2\"})\n    2\n    iex> Style.heading_level(%Style{id: \"test\", based_on: nil, type: :heading, name: \"HeAdInG 3\"})\n    3\n    iex> Style.heading_level(%Style{id: \"test\", based_on: nil, type: :paragraph, name: \"heading 1\"})\n    nil","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#heading_level/1-examples"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_blockquote/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_blockquote/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_code/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_code/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_definition/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_definition/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_definition_term/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_definition_term/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_heading/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_heading/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_inline_quote/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_inline_quote/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_paragraph/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_paragraph/1"},{"type":"macro","title":"NLdoc.Conversion.Reader.Docx.AST.Style.is_title/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#is_title/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.Style.style_type/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#t:style_type/0"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.AST.Style.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.AST.Style.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Convert","doc":"Converts a `Docx` struct into an NLdoc spec document, raising any errors that occur during the conversion.\n\nThis module implements a recursive conversion of the XML structure of a Word document into an NLdoc spec document.\nIts implementation in NLdoc was first written by Stephan Meijer and later refactored by Bart van Oort.\n\nHuge thanks to [Pandoc](https://github.com/jgm/pandoc) for inspiration and guidance on how to convert Word documents to a structured format.","ref":"NLdoc.Conversion.Reader.Docx.Convert.html"},{"type":"module","title":"Supported Features - NLdoc.Conversion.Reader.Docx.Convert","doc":"- [x] Title elements (becomes heading)\n- [x] Headings\n- [x] Text Paragraphs\n- [x] Definition lists, details and terms\n- [x] Preformatted blocks, also known as \"Source Code\"\n- [x] Text in Wingdings, Webdings and Symbol fonts is converted to UTF-8 equivalents\n- [-] Hyperlinks (missing support for `w:r` with `w:instrText` child that contains a hyperlink field code)\n- [-] Tables (missing support for colspan and rowspan, table captions)\n- [-] Ordered and Unordered lists (Windings as list characters are not implemented).\n- [-] Images (only in `w:drawing`, media is not yet exported to assets and missing support for captions)\n- [ ] Captions\n- [ ] LineBreak\n- [ ] Alternate content","ref":"NLdoc.Conversion.Reader.Docx.Convert.html#module-supported-features"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Convert.conversion/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Convert.html#t:conversion/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Convert.convert/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Convert.html#convert/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Convert.convert/2","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Convert.html#convert/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Convert.convert/3","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Convert.html#convert/3"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph","doc":"This module defines utility functions for converting Paragraphs.","ref":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.html"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.conversion/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.html#t:conversion/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.convert/5","doc":"Convert paragraph-based elements such as definitions, lists, paragraphs, headings.","ref":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.html#convert/5"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.spec_list/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.html#t:spec_list/0"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.spec_list_children/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Convert.Paragraph.html#t:spec_list_children/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files","doc":"This module provides functions to find specific files inside a Docx document.\n\nTODO: write proper tests for this module:\n1. extract a regular Zip file from fixtures\n2. Docx.Files.read(\"path/to/extracted/zip\")\n3. assert that the files are found correctly and the correct `Docx.Files` struct is returned\n4. assert that the `Docx.Files` struct can be used to find the correct files:\n  - `Docx.Files.document/1`\n  - `Docx.Files.core_properties/1`\n  - `Docx.Files.numberings/1`\n  - `Docx.Files.styles/1`\n  - `Docx.Files.relationships_of/2`","ref":"NLdoc.Conversion.Reader.Docx.Files.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.core_properties/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.html#core_properties/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.document/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.html#document/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.find_by_content_type/2","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.html#find_by_content_type/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.numberings/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.html#numberings/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.read/1","doc":"Read the contents of a directory containing an unzipped Docx file and parse the `[Content_Types].xml` file\nto return a `Docx.Files` struct that can be used with the rest of the functions in this module.","ref":"NLdoc.Conversion.Reader.Docx.Files.html#read/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.relationships_of/2","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.html#relationships_of/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.styles/1","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.html#styles/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes","doc":"Parsing for the \"[Content_Types].xml\" file inside a Docx document.","ref":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.parse/1","doc":"Parses the contents of a `[Content_Types].xml` file into a `ContentTypes` struct.","ref":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.html#parse/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.html#t:t/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.type/2","doc":"Returns the content type for a given filename.","ref":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.html#type/2"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Files.ContentTypes.type/2","doc":"iex> content_types = %ContentTypes{\n    ...>   defaults: %{\n    ...>     \"txt\" => \"text/plain\",\n    ...>     \"xml\" => \"application/xml\"\n    ...>   },\n    ...>   overrides: %{\n    ...>     \"/document.xml\" => \"application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml\"\n    ...>   }\n    ...> }\n    iex> content_types |> ContentTypes.type(\"/some/file.txt\")\n    \"text/plain\"\n    iex> content_types |> ContentTypes.type(\"/file.xml\")\n    \"application/xml\"\n    iex> content_types |> ContentTypes.type(\"/document.xml\")\n    \"application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml\"","ref":"NLdoc.Conversion.Reader.Docx.Files.ContentTypes.html#type/2-examples"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties","doc":"This module parses the core properties (`docProps/core.xml`) file in a Docx document\ninto a simple key-value map.","ref":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.convert/1","doc":"Converts a map of core properties into NLdoc spec descriptors to be set as metadata on the root document.","ref":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.html#convert/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.parse/1","doc":"Parses the contents of a Docx core properties (`docProps/core.xml`) file into a key-value map of all the properties.","ref":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.html#parse/1"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Files.CoreProperties.parse/1","doc":"iex> NLdoc.Conversion.Reader.Docx.Files.CoreProperties.parse(\n    ...>   {\"cp:coreProperties\", [], [\n    ...>     {\"dc:title\", [], [\"Jesus He Knows Me\"]},\n    ...>     {\"dc:creator\", [], [\"Genesis\"]},\n    ...>     {\"cp:keywords\", [], [\"song, music, satire, televangelists, religious hypocrisy, pop-rock, social commentary\"]},\n    ...>     {\"dc:description\", [], [\"Satirical song that mocks televangelists and religious hypocrisy, blending upbeat, catchy pop-rock with biting social commentary.\"]},\n    ...>     {\"cp:lastModifiedBy\", [], [\"Phil Collins\"]},\n    ...>     {\"cp:revision\", [], [\"42\"]},\n    ...>     {\"dcterms:created\", [{\"xsi:type\", \"dcterms:W3CDTF\"}], [\"1991-03-15T07:56:00Z\"]},\n    ...>     {\"dcterms:modified\", [{\"xsi:type\", \"dcterms:W3CDTF\"}], [\"1991-07-10T01:23:01Z\"]}\n    ...>   ]}\n    ...> )\n    %{\n      \"dc:title\" => \"Jesus He Knows Me\",\n      \"dc:creator\" => \"Genesis\",\n      \"cp:keywords\" => \"song, music, satire, televangelists, religious hypocrisy, pop-rock, social commentary\",\n      \"dc:description\" => \"Satirical song that mocks televangelists and religious hypocrisy, blending upbeat, catchy pop-rock with biting social commentary.\",\n      \"cp:lastModifiedBy\" => \"Phil Collins\",\n      \"cp:revision\" => \"42\",\n      \"dcterms:created\" => \"1991-03-15T07:56:00Z\",\n      \"dcterms:modified\" => \"1991-07-10T01:23:01Z\"\n    }","ref":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.html#parse/1-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.read!/1","doc":"Reads a (list of) Docx core properties file(s) at the given path(s) and parses it/them into a key-value map of all\nthe properties.","ref":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.html#read!/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.CoreProperties.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files.Document","doc":"This module provides a function for reading a Docx document.xml file\ninto a `NLdoc.Conversion.Reader.Docx.Files.Document` struct.","ref":"NLdoc.Conversion.Reader.Docx.Files.Document.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Document.read!/2","doc":"Reads a Docx document.xml file at the given path(s) and parses it into\nan `NLdoc.Conversion.Reader.Docx.Files.Document` struct.","ref":"NLdoc.Conversion.Reader.Docx.Files.Document.html#read!/2"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.Document.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.Document.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings","doc":"This module parses the numbering files (e.g. `word/numbering.xml`) in a Docx document\ninto a map mapping `{id, level}` tuples to numbering definitions, represented by\n`NLdoc.Conversion.Reader.Docx.AST.Numbering` structs.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html"},{"type":"module","title":"How does it work? - NLdoc.Conversion.Reader.Docx.Files.Numberings","doc":"Inside the numberings file, a set of numberings and abstract numberings are defined.\nThe numberings inherit it's properties from an abstract numbering. An example of this\nis illustrated below.\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n \n   \n     \n       \n       \n     \n     \n       \n       \n     \n   \n   \n     \n   \n   \n     \n     \n       \n     \n   \n \n```\n\nAn abstract numbering can define a set of properties, which the numberings\ncan inherit and/or override.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#module-how-does-it-work"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.abstract_numberings/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#t:abstract_numberings/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.get/2","doc":"Get the numbering definition referred to by a `NumberingProperties` struct\nor the numbering properties embedded in a `ParagraphProperties` struct.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#get/2"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Files.Numberings.get/2","doc":"iex> alias NLdoc.Conversion.Reader.Docx.AST.{Numbering, NumberingProperties, ParagraphProperties}\n    iex> import NLdoc.Conversion.Reader.Docx.Files.Numberings\n    iex> numberings = %{\n    ...>   {\"3\", 2} => %Numbering{id: \"3\", level: 2, format: \"X\", start: 3},\n    ...>   {\"3\", 1} => %Numbering{id: \"3\", level: 1, format: \"Y\", start: 2},\n    ...>   {\"2\", 1} => %Numbering{id: \"2\", level: 1, format: \"Y\", start: 2}}\n    iex> num_props = %NumberingProperties{num_id: \"3\", ilvl: 1}\n    iex> numberings |> get(num_props)\n    %Numbering{id: \"3\", level: 1, format: \"Y\", start: 2}\n    iex> numberings |> get(%ParagraphProperties{style_id: nil, num_properties: num_props})\n    %Numbering{id: \"3\", level: 1, format: \"Y\", start: 2}\n    iex> numberings |> get(nil)\n    nil","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#get/2-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.get/3","doc":"Get a numbering definition from a parsed map of numbering definitions by its ID and level.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#get/3"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Files.Numberings.get/3","doc":"iex> alias NLdoc.Conversion.Reader.Docx.AST.Numbering\n    iex> import NLdoc.Conversion.Reader.Docx.Files.Numberings\n    iex> numberings = %{\n    ...>   {\"3\", 2} => %Numbering{id: \"3\", level: 2, format: \"X\", start: 3},\n    ...>   {\"3\", 1} => %Numbering{id: \"3\", level: 1, format: \"Y\", start: 2},\n    ...>   {\"2\", 1} => %Numbering{id: \"2\", level: 1, format: \"Y\", start: 2}}\n    iex> get(numberings, \"3\", 1)\n    %Numbering{id: \"3\", level: 1, format: \"Y\", start: 2}\n    iex> get(numberings, \"3\", 5)\n    nil\n    iex> get(numberings, \"5\", 1)\n    nil","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#get/3-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.parse/1","doc":"Parses the numbering definitions in a `word/numbering.xml` file into a map mapping\n`{id, level}` tuples to `NLdoc.Conversion.Reader.Docx.AST.Numbering` structs.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#parse/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.read!/1","doc":"Reads a (list of) Docx numbering.xml file(s) at the given path(s) and parses it/them into\na single map as returned by `parse/1`.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#read!/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State","doc":"This module defines a struct that captures the state of the converter during a Docx conversion.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.get/2","doc":"Gets the given field from the state object.\n\nThis function only accepts fields of the state, which are :abstract_numberings, :numberings, :level, :abstract_numbering_id, :numbering_id.\nIt will raise if the field is not valid.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.html#get/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.keep/3","doc":"Modifies a state object by setting the given field to the value that field had in the old state.\n\nThis function only accepts fields of the state, which are :abstract_numberings, :numberings, :level, :abstract_numbering_id, :numbering_id.\nIt will raise if the field is not valid.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.html#keep/3"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.prepend/3","doc":"Prepends a list of values or a single value to the list field in the state object.\n\nThis function only accepts fields of the state, which are :abstract_numberings, :numberings.\nIt will raise if the field is not valid.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.html#prepend/3"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.set/3","doc":"Sets the given field on the state object to the given value.\n\nThis function only accepts fields of the state, which are :abstract_numberings, :numberings, :level, :abstract_numbering_id, :numbering_id.\nIt will raise if the field is not valid.","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.html#set/3"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.Numberings.State.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files.Relationship","doc":"This module provides functions for reading and parsing relationships files (e.g. `word/_rels/document.xml.rels`)\ninto a map mapping `{id, type}` tuples to `NLdoc.Conversion.Reader.Docx.AST.Relationship` structs.","ref":"NLdoc.Conversion.Reader.Docx.Files.Relationship.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Relationship.get/4","doc":"Get a relationship by its ID and type from a parsed map of relationships. The type can be a string\nequal to the relationship's `Type` attribute, or one of the atoms `:hyperlink` or `:image` to match\ntheir respective types.","ref":"NLdoc.Conversion.Reader.Docx.Files.Relationship.html#get/4"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Relationship.get_target/4","doc":"Get the target of a relationship by its ID and type from a parsed map of relationships.\nThe type can be a string equal to the relationship's `Type` attribute, or one of the atoms\n`:hyperlink` or `:image` to match their respective types.","ref":"NLdoc.Conversion.Reader.Docx.Files.Relationship.html#get_target/4"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Relationship.parse/1","doc":"Parses the contents of a relationships file (a `Relationships` XML element) into a map mapping\n`{id, type}` tuples to `NLdoc.Conversion.Reader.Docx.Files.Relationship` structs.","ref":"NLdoc.Conversion.Reader.Docx.Files.Relationship.html#parse/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Relationship.read!/1","doc":"Reads a Docx relationships (`.xml.rels`) file at the given path and parses it into\na single map as returned by `parse/1`.\n\nNote that multiple relationships files may reuse ID and type combinations from each other,\nso be careful of merging the results of reading multiple relationships files.","ref":"NLdoc.Conversion.Reader.Docx.Files.Relationship.html#read!/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.Relationship.rel_type/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.Relationship.html#t:rel_type/0"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.Relationship.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.Relationship.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Files.Styles","doc":"This module parses the styles (e.g. `word/styles.xml`) files in a Docx document\ninto a map mapping style IDs to `NLdoc.Conversion.Reader.Docx.AST.Style` structs.","ref":"NLdoc.Conversion.Reader.Docx.Files.Styles.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Styles.get/3","doc":"Get a style by its ID from a parsed map of styles.","ref":"NLdoc.Conversion.Reader.Docx.Files.Styles.html#get/3"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Styles.parse/1","doc":"Parses the styles from a `word/styles.xml` file into a map mapping style IDs to `NLdoc.Conversion.Reader.Docx.AST.Style` structs.","ref":"NLdoc.Conversion.Reader.Docx.Files.Styles.html#parse/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Files.Styles.read!/1","doc":"Reads a (list of) Docx styles.xml file(s) at the given path(s) and parses it/them into a single map\nof all the styles., as returned by `parse/1`.","ref":"NLdoc.Conversion.Reader.Docx.Files.Styles.html#read!/1"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.Files.Styles.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.Files.Styles.html#t:t/0"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.PostProcess","doc":"This module performs post-processing on the intermediate result of a Docx conversion\nto an NLdoc spec document with `NLdoc.Conversion.Reader.Docx.Convert`.\n\nThis post-processing essentially does the following:\n- Recursively reverse the order of the children of every spec object in the document.\n  This is done because `NLdoc.Conversion.Reader.Docx.Convert` accumulates all resources in reverse order,\n  as Elixir implements lists as linked lists and prepending to such a list is O(1),\n  while appending to a linked list is O(n).\n- If the Docx document had a Title element, increment the level of every heading in the document by 1.\n  Title elements are converted to a `Heading` with level 0, so in order to result in a valid NLdoc document,\n  if a document had a title heading, all headings must be incremented by 1.","ref":"NLdoc.Conversion.Reader.Docx.PostProcess.html"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.PostProcess.conversion/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.PostProcess.html#t:conversion/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.PostProcess.process/2","doc":"","ref":"NLdoc.Conversion.Reader.Docx.PostProcess.html#process/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.PostProcess.process/3","doc":"","ref":"NLdoc.Conversion.Reader.Docx.PostProcess.html#process/3"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.State","doc":"This module defines a struct that captures the state of the converter during a Docx conversion.","ref":"NLdoc.Conversion.Reader.Docx.State.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.State.get/2","doc":"Gets the given field from the state object.\n\nThis function only accepts fields of the state, which are :has_title, :hyperlink_target, :styling, :assets, :numbering_id.\nIt will raise if the field is not valid.","ref":"NLdoc.Conversion.Reader.Docx.State.html#get/2"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.State.keep/3","doc":"Modifies a state object by setting the given field to the value that field had in the old state.\n\nThis function only accepts fields of the state, which are :has_title, :hyperlink_target, :styling, :assets, :numbering_id.\nIt will raise if the field is not valid.","ref":"NLdoc.Conversion.Reader.Docx.State.html#keep/3"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.State.set/3","doc":"Sets the given field on the state object to the given value.\n\nThis function only accepts fields of the state, which are :has_title, :hyperlink_target, :styling, :assets, :numbering_id.\nIt will raise if the field is not valid.","ref":"NLdoc.Conversion.Reader.Docx.State.html#set/3"},{"type":"type","title":"NLdoc.Conversion.Reader.Docx.State.t/0","doc":"","ref":"NLdoc.Conversion.Reader.Docx.State.html#t:t/0"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.State.upsert_asset/2","doc":"Upserts the existence of an asset based on it's relative path.","ref":"NLdoc.Conversion.Reader.Docx.State.html#upsert_asset/2"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.State.upsert_asset/2","doc":"iex> alias NLdoc.Conversion.Reader.Docx.State\n    iex> {uuid, state} = State.upsert_asset(%State{}, \"media/image.png\")\n    iex> %{\"media/image.png\" => ^uuid} = state.assets\n\n    iex> alias NLdoc.Conversion.Reader.Docx.State\n    iex> {\"xyz\", state} = State.upsert_asset(%State{assets: %{\"media/image.png\" => \"xyz\"}}, \"media/image.png\")\n    iex> %{\"media/image.png\" => \"xyz\"} = state.assets","ref":"NLdoc.Conversion.Reader.Docx.State.html#upsert_asset/2-examples"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.Util.Helpers","doc":"This module defines utility functions for the NLdoc spec objects.","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Util.Helpers.add/2","doc":"Adds a resource to the list of resources. If possible, merges it with the head of the list using `merge/2`.\nEnsures that the added resource has an ID by calling `add_id/1` if necessary.","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add/2"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Util.Helpers.add/2","doc":"Adding a resource without an ID to an empty list:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.Text\n    iex> [%Text{text: \"Hello\", styling: [:bold], id: id}] = add([], %Text{text: \"Hello\", styling: [:bold], id: nil})\n    [%Text{text: \"Hello\", styling: [:bold], id: id}]\n    iex> Ecto.UUID.cast(id)\n    {:ok, id}\n\nAdding a resource that can be merged with the head of the list:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.Text\n    iex> res1 = %Text{id: \"1\", text: \"Hello\", styling: [:bold]}\n    iex> res2 = %Text{id: \"2\", text: \" World\", styling: [:bold]}\n    iex> add([res1], res2)\n    [%Text{id: \"1\", styling: [:bold], text: \"Hello World\"}]\n\nAdding a resource that cannot be merged:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.Text\n    iex> res1 = %Text{id: \"1\", text: \"Hello\", styling: [:bold]}\n    iex> res2 = %Text{id: \"2\", text: \" World\", styling: [:italic]}\n    iex> add([res1], res2)\n    [res2, res1]","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add/2-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Util.Helpers.add_all/2","doc":"Adds all resources from the second list to the first list, using `add/2` to merge them where possible.","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_all/2"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Util.Helpers.add_all/2","doc":"iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.Text\n    iex> existing_resources = [\n    ...>   %Text{text: \" \", styling: [:bold]},\n    ...>   %Text{text: \"message:\", styling: [:italic]}\n    ...> ]\n    iex> new_resources = [\n    ...>   %Text{text: \" World\", styling: [:bold]},\n    ...>   %Text{text: \"Hello\", styling: [:bold]}\n    ...> ]\n    iex> add_all(existing_resources, new_resources)\n    [\n      %Text{text: \" Hello World\", styling: [:bold]},\n      %Text{text: \"message:\", styling: [:italic]}\n    ]\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.Text\n    iex> new_resources = [\n    ...>   %Text{text: \"Hello\", styling: [:bold]},\n    ...>   %Text{text: \"World\", styling: [:italic]}\n    ...> ]\n    iex> [%{id: id1}, %{id: id2}] = add_all([], new_resources)\n    [\n      %Text{styling: [:bold], text: \"Hello\", id: id1},\n      %Text{styling: [:italic], text: \"World\", id: id2}\n    ]","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_all/2-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Util.Helpers.add_child/2","doc":"Adds a child to the resource's list of children.","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_child/2"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Util.Helpers.add_child/2","doc":"Adding a child to a resource without children:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.{Paragraph, Text}\n    iex> resource = %Paragraph{children: []}\n    iex> child = %Text{styling: [:bold], text: \"Hello World\"}\n    iex> %Paragraph{children: [%Text{id: id}]} =  add_child(resource, child)\n    %Paragraph{children: [%Text{id: id, styling: [:bold], text: \"Hello World\"}]}\n\nAdding a child to a resource with matching text children, effectively merging:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.{Paragraph, Text}\n    iex> resource = %Paragraph{children: [%Text{id: \"abc\", styling: [:bold], text: \"Hello\"}]}\n    iex> child = %Text{styling: [:bold], text: \" World\"}\n    iex> add_child(resource, child)\n    %Paragraph{children: [%Text{id: \"abc\", styling: [:bold], text: \"Hello World\"}]}\n\nAdding a child to a resource with children:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.{Paragraph, Text}\n    iex> first_text = %Text{id: \"abc\", styling: [:bold], text: \"Hello\"}\n    iex> second_text = %Text{id: \"xyz\", styling: [:italic], text: \" World\"}\n    iex> resource = %Paragraph{children: [first_text]}\n    iex> add_child(resource, second_text)\n    %Paragraph{children: [second_text, first_text]}","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_child/2-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Util.Helpers.add_children/2","doc":"Adds multiple children to the resource's list of children.","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_children/2"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Util.Helpers.add_children/2","doc":"Adding multiple children to a resource without children:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.{Paragraph, Text}\n    iex> resource = %Paragraph{children: []}\n    iex> children = [\n    ...>   %Text{styling: [:bold], text: \"Hello\"},\n    ...>   %Text{styling: [:italic], text: \" World\"}\n    ...> ]\n    iex> %{children: [%{id: id1}, %{id: id2}]} = add_children(resource, children)\n    %Paragraph{children: [%Text{id: id1, styling: [:bold], text: \"Hello\"}, %Text{id: id2, styling: [:italic], text: \" World\"}]}\n\nAdding multiple children to a resource with children, with merging:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> alias NLdoc.Spec.{Paragraph, Text}\n    iex> first_text = %Text{id: \"abc\", styling: [:bold], text: \"Hello\"}\n    iex> second_text = %Text{id: \"xyz\", styling: [:bold], text: \" World\"}\n    iex> resource = %Paragraph{children: [first_text]}\n    iex> add_children(resource, [second_text])\n    %Paragraph{children: [%Text{id: \"abc\", styling: [:bold], text: \"Hello World\"}]}","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_children/2-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Util.Helpers.add_id/1","doc":"Assigns a new unique identifier (UUID) to the resource if it doesn't already have one.\nIf the resource already has an `id`, it is returned unchanged.","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_id/1"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Util.Helpers.add_id/1","doc":"When the resource doesn't have an `id`:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> %{name: \"test\", id: id} = add_id(%{name: \"test\", id: nil})\n    iex> Ecto.UUID.cast(id)\n    {:ok, id}\n\nWhen the resource already has an `id`:\n\n    iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> existing_id = Ecto.UUID.generate()\n    iex> resource = %{name: \"test\", id: existing_id}\n    iex> add_id(resource)\n    %{name: \"test\", id: existing_id}","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#add_id/1-examples"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.Util.Helpers.new_id/0","doc":"Generates a new unique identifier (UUID) as a string.","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#new_id/0"},{"type":"function","title":"Examples - NLdoc.Conversion.Reader.Docx.Util.Helpers.new_id/0","doc":"iex> import NLdoc.Conversion.Reader.Docx.Util.Helpers\n    iex> id = new_id()\n    iex> Ecto.UUID.cast(id)\n    {:ok, id}","ref":"NLdoc.Conversion.Reader.Docx.Util.Helpers.html#new_id/0-examples"},{"type":"module","title":"NLdoc.Conversion.Reader.Docx.XML","doc":"`NLdoc.Conversion.Docx.XML` implements functions for reading and parsing XML files.","ref":"NLdoc.Conversion.Reader.Docx.XML.html"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.XML.parse/1","doc":"Parses the given XML data into a `Saxy.XML.element` tuple.\n\nThis function returns `{:ok, element}` on success or `{:error, error}` with a `Saxy.ParseError` if `Saxy` fails to parse the XML.","ref":"NLdoc.Conversion.Reader.Docx.XML.html#parse/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.XML.parse!/1","doc":"Parses the given XML data into a `Saxy.XML.element` tuple.\n\nThis function raises a `Saxy.ParseError` if `Saxy` fails to parse the XML.","ref":"NLdoc.Conversion.Reader.Docx.XML.html#parse!/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.XML.read/1","doc":"Reads an XML file at the given path and parses it into a `Saxy.XML.element` tuple.\nThe file is assumed to be UTF-8 encoded and the BOM (Byte Order Mark) at the beginning of the file is trimmed.\n\nThis function returns `{:ok, element}` on success or `{:error, error}` with a `File.Error` or a `Saxy.ParseError`\nif the file cannot be read or if `Saxy` fails to parse the XML.","ref":"NLdoc.Conversion.Reader.Docx.XML.html#read/1"},{"type":"function","title":"NLdoc.Conversion.Reader.Docx.XML.read!/1","doc":"Reads an XML file at the given path and parses it into a `Saxy.XML.element` tuple.\nThe file is assumed to be UTF-8 encoded and the BOM (Byte Order Mark) at the beginning of the file is trimmed.\n\nThis function raises an error if the file cannot be read or if `Saxy` fails to parse the XML.","ref":"NLdoc.Conversion.Reader.Docx.XML.html#read!/1"},{"type":"extras","title":"NLdoc.Conversion.Reader.Docx","doc":"# NLdoc.Conversion.Reader.Docx","ref":"readme.html"},{"type":"extras","title":"Installation - NLdoc.Conversion.Reader.Docx","doc":"Add `nldoc_conversion_reader_docx` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nldoc_conversion_reader_docx, \"~> 1.0.0\"}\n  ]\nend\n```\n\nThen, fetch dependencies:\n\n```sh\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - NLdoc.Conversion.Reader.Docx","doc":"Detailed documentation is available at [HexDocs](https://hexdocs.pm/nldoc_conversion_reader_docx).","ref":"readme.html#documentation"},{"type":"extras","title":"License - NLdoc.Conversion.Reader.Docx","doc":"This project is licensed under the [EUPL-1.2 License](https://joinup.ec.europa.eu/software/page/eupl).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [1.0.28](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.27...1.0.28) (2025-04-06)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.10 ([eb3e4c9](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/eb3e4c946f6d7c8beee06dbfb957089be0235d86))\n\n## [1.0.27](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.26...1.0.27) (2025-04-03)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* update references (GitLab migration) ([5ee9c86](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/5ee9c86f76c2260a351ea4e60916cfaf5f630c52))\n\n## [1.0.26](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.25...1.0.26) (2025-04-02)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.9 ([f643728](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/f64372827189184e807657eea1b0aa260f5803ce))\n\n## [1.0.25](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.24...1.0.25) (2025-04-02)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_test to v3.0.5 ([afea37d](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/afea37d3ffd0291a877424b1094ced946268bc46))\n\n## [1.0.24](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.23...1.0.24) (2025-04-02)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency mimic to v1.11.2 ([02b7d1c](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/02b7d1cd0022f78cfb30c4d07143e2e1aae8dfe3))\n\n## [1.0.23](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.22...1.0.23) (2025-03-31)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_test to v3.0.4 ([b120caf](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/b120cafec99e13222a7bf80a20139cc2b76cd3a0))\n\n## [1.0.22](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.21...1.0.22) (2025-03-31)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.7 ([f9baba4](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/f9baba45073f0dbdccdad423c987255af73889d4))\n\n## [1.0.21](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.20...1.0.21) (2025-03-31)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.6 ([ac3a499](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/ac3a4995f2166b3bde0786bab3d90b6e43195214))\n\n## [1.0.20](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.19...1.0.20) (2025-03-30)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.5 ([b6c83c7](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/b6c83c7850c496946a0a8b3c5daca708049099cb))\n\n## [1.0.19](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.18...1.0.19) (2025-03-29)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency mimic to v1.11.1 ([ae2ee2b](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/ae2ee2bcd9438530bf5047ee761554121eea5894))\n\n## [1.0.18](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.17...1.0.18) (2025-03-10)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_test to v3.0.3 ([c76870a](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/c76870afd23e56b427d5619d43f3854693d5800c))\n\n## [1.0.17](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.16...1.0.17) (2025-03-10)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.4 ([39849a2](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/39849a2476ead14f317a5cb23fd7cd7358367e0d))\n\n## [1.0.16](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.15...1.0.16) (2025-03-09)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.3 ([86e42eb](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/86e42eba305085cfd3ff17fc920a9a98d52e3d1f))\n* **deps:** update dependency simple_form to v1.0.9 ([14d3cf4](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/14d3cf497fa3b878517313ea95cbdc6e7356c760))\n\n## [1.0.15](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.14...1.0.15) (2025-03-08)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.2 ([d3607ec](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/d3607ecd006a4f05538214148202ca66cefdc53d))\n\n## [1.0.14](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.13...1.0.14) (2025-03-07)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency ex_doc to v0.37.3 ([0ba25e2](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/0ba25e29aca9e79351f5d83b0d7ae4f13aaf4d3c))\n\n## [1.0.13](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.12...1.0.13) (2025-02-27)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.1 ([25b0952](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/25b095243a74979f7adce4a4917632bd13dfce78))\n\n## [1.0.12](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.11...1.0.12) (2025-02-25)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.3.0 ([eae35cb](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/eae35cb0bf8ba5fb52f06f35dc12caabbd9d0677))\n\n## [1.0.11](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.10...1.0.11) (2025-02-23)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.2.5 ([7a89718](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/7a89718d333290be5e5b8b9a4f4c88d0efef8e07))\n\n## [1.0.10](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.9...1.0.10) (2025-02-22)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.2.4 ([233ae2b](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/233ae2b4217de12427097331d3be9c5fa7a68ed1))\n* **deps:** update dependency nldoc_test to v3.0.2 ([7458634](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/7458634dab03939f34f86bf3e039b6f9cc397f1f))\n* **deps:** update dependency simple_form to v1.0.8 ([7edab40](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/7edab40825e710ad66a8330c8c345669341cfa64))\n\n## [1.0.9](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.8...1.0.9) (2025-02-20)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency ex_doc to v0.37.2 ([9ef1eb9](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/9ef1eb9fdc897e609a187b18ec10a0788e8d8f96))\n\n## [1.0.8](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.7...1.0.8) (2025-02-14)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.2.3 ([fce3cb5](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/fce3cb58f570bf848d53e8efad2bf14d5088d26a))\n\n## [1.0.7](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.6...1.0.7) (2025-02-13)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_test to v3.0.1 ([ee0df51](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/ee0df51e9a23133270419ec7d7f86d6fdbf90d27))\n* **deps:** update dependency simple_form to v1.0.7 ([e67889b](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/e67889bfd63161d9e22922365576057ab7fccbc1))\n\n## [1.0.6](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.5...1.0.6) (2025-02-12)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency nldoc_spec to v1.2.1 ([74d0c1a](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/74d0c1aae93123baa6018f9f0684024c876aa98e))\n\n## [1.0.5](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.4...1.0.5) (2025-02-11)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency ex_doc to ~> 0.37 ([b41ab2a](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/b41ab2a76a8c2772056cfa1ea1953397cccb4172))\n\n## [1.0.4](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.3...1.0.4) (2025-02-06)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **NLD-625:** Packaging entire lib/ directory ([a15981c](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/a15981c5c260eb420712798096ebcab4256d70ff))\n\n## [1.0.3](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.2...1.0.3) (2025-02-06)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **NLD-625:** Set mimic to be dev dependency ([f408beb](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/f408beb1c4a991907a429fc9650ff2e4bc166897))\n\n## [1.0.2](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.1...1.0.2) (2025-02-06)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **NLD-625:** Correct file location of docx.ex ([5a40d96](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/5a40d96b83cdb0fd13ecd61de8b73deb48dbc9ae))\n\n## [1.0.1](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/compare/1.0.0...1.0.1) (2025-02-06)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **NLD-625:** Correct file locations ([e5cb186](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/e5cb186dfdb9055205e1f636764db6ea06b5717c))\n\n# 1.0.0 (2025-02-06)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Features - Changelog","doc":"* **NLD-625:** initial commit ([0171715](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_conversion_reader_docx/commit/01717155c2a673efb52c77bf8ac7bbdcc510f2d8))","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}